@@ -67,7 +67,9 @@ def load(mock, parameters):
                        dbus.Dictionary({
                            'IdleHint': parameters.get('IdleHint', False),
                            'IdleAction': parameters.get('IdleAction', 'ignore'),
-                           'IdleSinceHint': parameters.get('IdleSinceHint', None),
+                           'IdleSinceHint': dbus.UInt64(parameters.get('IdleSinceHint', 0)),
+                           'IdleSinceHintMonotonic': dbus.UInt64(parameters.get('IdleSinceHintMonotonic', 0)),
+                           'IdleActionUSec': dbus.UInt64(parameters.get('IdleActionUSec', 1)),
                            'PreparingForShutdown': parameters.get('PreparingForShutdown', False),
                            'PreparingForSleep': parameters.get('PreparingForSleep', False),
                            'PreparingForShutdown': parameters.get('PreparingForShutdown', False),
